==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesDescriptionMetadata.c(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicXYTriangulatingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
            a.item("LongitudeMemberPath", "String");
            a.item("LatitudeMemberPath", "String");
            a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
            a.item("TriangleVertexMemberPath1", "String");
            a.item("TriangleVertexMemberPath2", "String");
            a.item("TriangleVertexMemberPath3", "String");
        }
        static d(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.b(a);
            a.ac("GeographicXYTriangulatingSeries", GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesDescriptionMetadata, 'GeographicXYTriangulatingSeriesDescriptionMetadata');
    GeographicXYTriangulatingSeriesDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesDescriptionMetadata.c(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicXYTriangulatingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
            a.item("LongitudeMemberPath", "String");
            a.item("LatitudeMemberPath", "String");
            a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
            a.item("TriangleVertexMemberPath1", "String");
            a.item("TriangleVertexMemberPath2", "String");
            a.item("TriangleVertexMemberPath3", "String");
        }
        static d(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.b(a);
            a.ad("GeographicXYTriangulatingSeries", GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesDescriptionMetadata, 'GeographicXYTriangulatingSeriesDescriptionMetadata');
    GeographicXYTriangulatingSeriesDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesDescriptionMetadata;
})();
